@@ -3,14 +3,30 @@ package Wiki::Toolkit::Plugin::JSON;
 use strict;
 
 use vars qw( $VERSION );
-$VERSION = '0.04';
+$VERSION = '0.01';
 
-use JSON;
 use POSIX 'strftime';
 use Time::Piece;
 use URI::Escape;
 use Carp qw( croak );
 
+BEGIN {
+    require constant;
+    eval {
+        require JSON::Syck;
+        JSON::Syck->import();
+    };
+
+    unless ($@) {
+        constant->import( JSON_SYCK => 1 );
+    }
+    else {
+        eval { require JSON; JSON->import() };
+        die "Couldn't find a JSON Package, install JSON::Syck or JSON" if $@;
+        constant->import( JSON_SYCK => 0 );
+    }
+}
+
 sub new {
     my $class = shift;
     my $self  = {@_};
@@ -93,7 +109,7 @@ sub recent_changes {
               $self->{make_history_url}->( $change->{name} );
         }
 
-        $change->{node_url} = $self->{make_node_url}->( $change->{name} );
+        my $change->{node_url} = $self->{make_node_url}->( $change->{name} );
 
         my $rdf_url = $change->{node_url};
         $rdf_url =~ s/\?/\?id=/;
@@ -112,7 +128,12 @@ sub recent_changes {
 
 sub make_json {
     my ( $self, $data ) = @_;
-    return JSON::to_json( $data );
+    if (JSON_SYCK) {
+        return JSON::Syck::Dump($data);
+    }
+    else {
+        return JSON::objToJson($data);
+    }
 }
 
 1;
@@ -284,8 +305,6 @@ Earle Martin <EMARTIN@cpan.org>. Originally by Kake Pugh <kake@earth.li>.
 Copyright 2003-4 Kake Pugh. Subsequent modifications copyright 2005 
 Earle Martin.
 
-Copyright 2008 the Wiki::Toolkit team
-
 This module is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
